@@ -2,18 +2,18 @@ package HTML::FormFu::Constraint;
 
 use strict;
 use base 'HTML::FormFu::Processor';
-use Class::C3;
+use mro 'c3';
 
 use HTML::FormFu::Exception::Constraint;
 use HTML::FormFu::Util qw(
     DEBUG_CONSTRAINTS
     debug
 );
+use Carp qw( croak );
+use Clone ();
 use List::MoreUtils qw( any );
 use List::Util qw( first );
 use Scalar::Util qw( reftype blessed );
-use Storable qw( dclone );
-use Carp qw( croak );
 
 __PACKAGE__->mk_accessors(qw( only_on_reps ));
 
@@ -229,7 +229,7 @@ sub clone {
     my $clone = $self->next::method(@_);
 
     if ( defined( my $when = $self->when ) ) {
-        $clone->when( dclone $when );
+        $clone->when( Clone::clone $when );
     }
 
     return $clone;
@@ -342,7 +342,7 @@ Arguments: $string
 Variant of L</message> which uses L<localize|HTML::FormFu/localize> to
 create the message.
 
-=head2 localise_args
+=head2 localize_args
 
 Provide arguments that should be passed to L<localize|HTML::FormFu/localize>
 to replace C<[_1]>, C<[_2]>, etc. in the localized string.
@@ -492,3 +492,5 @@ Sebastian Riedel, C<sri@oook.de>.
 
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
+
+=cut
