@@ -2,7 +2,7 @@ package HTML::FormFu::Element::Hr;
 
 use strict;
 use base 'HTML::FormFu::Element::_NonBlock';
-use Class::C3;
+use mro 'c3';
 
 sub new {
     my $self = shift->next::method(@_);
@@ -18,7 +18,7 @@ __END__
 
 =head1 NAME
 
-HTML::FormFu::Element::Hr
+HTML::FormFu::Element::Hr - horizontal-rule element
 
 =head1 DESCRIPTION
 
@@ -30,7 +30,7 @@ Is a sub-class of, and inherits methods from
 L<HTML::FormFu::Element::NonBlock>, 
 L<HTML::FormFu::Element>
 
-L<HTML::FormFu::FormFu>
+L<HTML::FormFu>
 
 =head1 AUTHOR
 
@@ -40,3 +40,5 @@ Carl Franks, C<cfranks@cpan.org>
 
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
+
+=cut
