@@ -2,44 +2,40 @@ package HTML::FormFu::Element::Multi;
 
 use strict;
 use base 'HTML::FormFu::Element::Block', 'HTML::FormFu::Element::_Field';
-use Class::C3;
+use mro 'c3';
 
-use HTML::FormFu::Element::_Field qw/ :FIELD /;
+use HTML::FormFu::Element::_Field qw( :FIELD );
 use HTML::FormFu::Util
-    qw/ append_xml_attribute xml_escape process_attrs _parse_args _get_elements _filter_components /;
-use Storable qw/ dclone /;
+    qw( append_xml_attribute xml_escape process_attrs _parse_args _get_elements _filter_components );
+use Clone ();
 
-__PACKAGE__->mk_accessors(
-    qw/
+__PACKAGE__->mk_item_accessors( qw(
         field_filename
         label_filename
         javascript
         container_tag
         label_tag
-        /
-);
+) );
 
-__PACKAGE__->mk_output_accessors(
-    qw/
-        comment label value
-        /
-);
+__PACKAGE__->mk_output_accessors(qw( comment label value ));
 
-__PACKAGE__->mk_attrs(
-    qw/
+__PACKAGE__->mk_attrs( qw(
         comment_attributes
         container_attributes
         label_attributes
-        /
-);
+) );
+
+*default     = \&value;
+*default_xml = \&value_xml;
+*default_loc = \&value_loc;
 
 sub new {
     my $self = shift->next::method(@_);
 
     $self->comment_attributes(   {} );
     $self->container_attributes( {} );
+    $self->label_attributes(     {} );
     $self->filename('multi');
-    $self->label_attributes( {} );
     $self->label_filename('label');
     $self->label_tag('label');
 
@@ -187,7 +183,7 @@ sub string {
             $html .= $elem->_string_field($render);
 
             if ( defined $elem->label ) {
-                $html .= "\n" . $elem->_string_label($render);
+                $html .= sprintf "\n%s", $elem->_string_label($render);
             }
         }
         else {
@@ -215,9 +211,9 @@ sub clone {
 
     my $clone = $self->next::method(@_);
 
-    $clone->comment_attributes( dclone $self->comment_attributes );
-    $clone->container_attributes( dclone $self->container_attributes );
-    $clone->label_attributes( dclone $self->label_attributes );
+    $clone->comment_attributes( Clone::clone $self->comment_attributes );
+    $clone->container_attributes( Clone::clone $self->container_attributes );
+    $clone->label_attributes( Clone::clone $self->label_attributes );
 
     return $clone;
 }
@@ -246,7 +242,7 @@ Is a sub-class of, and inherits methods from
 L<HTML::FormFu::Element::_Field>, 
 L<HTML::FormFu::Element>
 
-L<HTML::FormFu::FormFu>
+L<HTML::FormFu>
 
 =head1 AUTHOR
 
@@ -256,3 +252,5 @@ Carl Franks, C<cfranks@cpan.org>
 
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
+
+=cut
