@@ -2,7 +2,7 @@ package HTML::FormFu::Element::_Input;
 
 use strict;
 use base 'HTML::FormFu::Element::_Field';
-use Class::C3;
+use mro 'c3';
 
 use HTML::FormFu::ObjectUtil qw( _coerce );
 use HTML::FormFu::Util qw( process_attrs );
@@ -122,3 +122,5 @@ Carl Franks, C<cfranks@cpan.org>
 
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
+
+=cut
