@@ -2,7 +2,7 @@ package HTML::FormFu::Element::_NonBlock;
 
 use strict;
 use base 'HTML::FormFu::Element';
-use Class::C3;
+use mro 'c3';
 
 use HTML::FormFu::Util qw( process_attrs );
 
@@ -77,3 +77,5 @@ Carl Franks, C<cfranks@cpan.org>
 
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
+
+=cut
